@@ -30,7 +30,7 @@ import (
 	tugit "github.com/b4nst/turbogit/pkg/git"
 	"github.com/b4nst/turbogit/pkg/integrations"
 
-	git "github.com/libgit2/git2go/v31"
+	git "github.com/libgit2/git2go/v33"
 	"github.com/spf13/cobra"
 )
 
@@ -51,7 +51,7 @@ var branchCmd = &cobra.Command{
 	Long: `
 If you don't give any argument, the command will look for issue in pre-configured issues provider.
 The issue ID will be used as a prefix.
-If type=user, a prefix with your git username will be added to the branch name.
+If type=user(s), a prefix with your git username will be added to the branch name.
 	`,
 	Example: `
 # Create branch feat/my-feature from current branch
@@ -84,6 +84,28 @@ func runBranchCmd(cmd *cobra.Command, args []string) {
 	}
 }
 
+func promptProviderBranch(repo *git.Repository) (nb format.TugBranch, err error) {
+	providers, err := integrations.ProvidersFrom(repo)
+	if err != nil {
+		return nb, err
+	}
+	issues := []integrations.IssueDescription{}
+	for _, p := range providers {
+		// TODO concurrent search
+		pIssues, err := p.Search()
+		if err != nil {
+			return nb, err
+		}
+		issues = append(issues, pIssues...)
+	}
+	issue, err := integrations.SelectIssue(issues, false)
+	if err != nil {
+		return nb, err
+	}
+
+	return issue.ToBranch(format.DefaultTypeRewrite), nil
+}
+
 func parseBranchCmd(cmd *cobra.Command, args []string) (*BranchCmdOption, error) {
 	// Find repo
 	repo, err := tugit.Getrepo()
@@ -94,40 +116,28 @@ func parseBranchCmd(cmd *cobra.Command, args []string) (*BranchCmdOption, error)
 	var nb format.TugBranch
 
 	if len(args) == 0 {
-		providers, err := integrations.ProvidersFrom(repo)
+		nb, err = promptProviderBranch(repo)
 		if err != nil {
 			return nil, err
 		}
-		issues := []integrations.IssueDescription{}
-		for _, p := range providers {
-			// TODO concurrent search
-			pIssues, err := p.Search()
-			if err != nil {
-				return nil, err
-			}
-			issues = append(issues, pIssues...)
-		}
-		issue, err := integrations.SelectIssue(issues, false)
-		if err != nil {
-			return nil, err
-		}
-		nb = issue.ToBranch(format.DefaultTypeRewrite)
 	} else {
 		nb = format.TugBranch{
 			Description: strings.Join(args[1:], " "),
 		}.WithType(args[0], format.DefaultTypeRewrite)
-		if nb.Type == "user" {
-			// Get user name from config
-			config, err := repo.Config()
-			if err != nil {
-				return nil, err
-			}
-			username, _ := config.LookupString("user.name")
-			if username == "" {
-				return nil, errors.New("You need to configure your username before creating a user branch.")
-			}
-			nb.Prefix = username
+	}
+
+	// User(s) branch
+	if nb.Type == "user" || nb.Type == "users" {
+		// Get user name from config
+		config, err := repo.Config()
+		if err != nil {
+			return nil, err
 		}
+		username, _ := config.LookupString("user.name")
+		if username == "" {
+			return nil, errors.New("You need to configure your username before creating a user branch.")
+		}
+		nb.Prefix = username
 	}
 
 	return &BranchCmdOption{
