@@ -25,12 +25,8 @@ import (
 	"fmt"
 	"log"
 	"os"
-	"path"
 
 	"github.com/spf13/cobra"
-
-	homedir "github.com/mitchellh/go-homedir"
-	"github.com/spf13/viper"
 )
 
 const (
@@ -41,15 +37,13 @@ var (
 	Version   = "dev"
 	Commit    = "nil"
 	BuildDate = "nil"
+
+	RootCmd = &cobra.Command{
+		Use:   BIN_NAME,
+		Short: "Improve your git workflow.",
+	}
 )
 
-var cfgFile string
-
-var RootCmd = &cobra.Command{
-	Use:   BIN_NAME,
-	Short: "Improve your git workflow.",
-}
-
 func Execute() {
 	if err := RootCmd.Execute(); err != nil {
 		fmt.Println(err)
@@ -59,30 +53,4 @@ func Execute() {
 
 func init() {
 	log.SetFlags(0)
-	cobra.OnInitialize(initConfig)
-
-	RootCmd.PersistentFlags().StringVar(&cfgFile, "config", "", fmt.Sprintf("config file (default is $HOME/.config/%s/%s.toml)", BIN_NAME, BIN_NAME))
-}
-
-// initConfig reads in config file and ENV variables if set.
-func initConfig() {
-	if cfgFile != "" {
-		// Use config file from the flag.
-		viper.SetConfigFile(cfgFile)
-	} else {
-		// Find home directory.
-		home, err := homedir.Dir()
-		if err != nil {
-			fmt.Println(err)
-			os.Exit(1)
-		}
-
-		viper.AddConfigPath(path.Join(home, ".config", BIN_NAME))
-		viper.SetConfigType("toml")
-		viper.SetConfigName(BIN_NAME)
-	}
-
-	viper.AutomaticEnv() // read in environment variables that match
-
-	viper.ReadInConfig()
 }
